@@ -1,2 +1,2 @@
-from get_page import *
+from .get_page import *
 __all__ = ['get_page']
